==> vee_2.4-2.tar.gz: vee-2.4/src/child/gvim.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk, os, time, base64, marshal
import GConf, child, Label, __BASIC__, TAB, Conf, func, i18n

_ = i18n.gettext()

class egg (__BASIC__.egg) :

	CHILD_TYPE = child.TYPE_GVIM
	SIGNAL_REMOVE = "plug-removed"

	SERVERNAME = "VEE_%s"
	STR_SERVERNAME = "VEE_%s"
	VIM_TITLESTRING = "\033:set title titlestring=%t\n:\n\n"

	FILENAME = str()

	def __init__ (self, **kwargs) :
		__BASIC__.egg.__init__(self, **kwargs)

		if kwargs.has_key("filename") :
			if kwargs["filename"] : self.FILENAME = kwargs["filename"]

		self.GCONF_CLIENT = GConf.Client()
		self.GVIM_COMMAND = \
			self.GCONF_CLIENT.get_value(Conf.SCHEMA["command-gvim"]["key"])

	def make (self) :
		self.WIDGET = gtk.Socket()
		self.WIDGET.set_property("has-focus", True)
		self.WIDGET.set_property("can-default", True)
		self.WIDGET.set_property("can-focus", True)
		self.WIDGET.set_property("is-focus", True)
		self.WIDGET.set_property("sensitive", True)
		self.WIDGET.set_property("receives-default", True)
		self.WIDGET.show()

	def start (self) :
		self.PLUG_ADDED = 1

		__chdir = ""
		if self.FILENAME :
			self.FILENAME = func.escape_path(self.FILENAME)
			__chdir = "cd %s;" % \
				func.escape_path(os.path.dirname(self.FILENAME))
			self.store_recent()

		self.SERVERNAME = self.STR_SERVERNAME % int(time.time())
		os.system("%s %s --socketid %i --servername %s %s" % \
			(__chdir, self.GVIM_COMMAND, \
				self.WIDGET.get_id(), self.SERVERNAME, self.FILENAME))

	def openFile (self, filename) :
		self.FILENAME = filename
		self.remote(filename, "isFile")
		self.store_recent()

	def remote (self, command, isfile=False) :
		__chdir = ""
		if isfile :
			__chdir = "cd %s;" % \
				func.escape_path(os.path.dirname(command))

		os.system( \
			"%s %s --servername \"%s\" --remote \"%s\"" % \
			(__chdir, self.GVIM_COMMAND, self.SERVERNAME, command))

	def remote_send (self, command) :
		os.system( \
			"%s --servername \"%s\" --remote-send \"%s\"" % \
			(self.GVIM_COMMAND, self.SERVERNAME, command))

	def get_title (self) :
		return self.FILENAME

	def exit (self) :
		self.remote_send("\033:qa<CR>")

	def store_recent (self) :
		__data = self.GCONF_CLIENT.get_value( \
			Conf.SCHEMA["recent-opened-files"]["key"])

		list_files = list()
		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_files = __data1
		except EOFError :
			pass

		if self.FILENAME in list_files :
			# remove old one and make new one be 1st.
			del(list_files[list_files.index(self.FILENAME)])

		list_files = [self.FILENAME,] + list_files

		__data = marshal.dumps(list_files)
		__data0 = base64.encodestring(__data)

		self.GCONF_CLIENT.set_value_by_conf( \
			"recent-opened-files", \
			__data0 \
		)

class tab (__BASIC__.tab) :

	LABEL_NAME = _("GVIM")
	FILENAME = None
	OPEN_IN_THIS_PAGE = False

	def __init__ (self, state, **kwargs) :

		__BASIC__.tab.__init__(self, state, **kwargs)

		if kwargs.has_key("filename") :
			#if os.path.exists(kwargs["filename"]) :
			#	self.FILENAME = kwargs["filename"]
			self.FILENAME = kwargs["filename"]

		if kwargs.has_key("openInThisPage") :
			self.OPEN_IN_THIS_PAGE = kwargs["openInThisPage"]

	def getEgg (self) :
		self.EGG = egg(filename=self.FILENAME)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		if not self.OPEN_IN_THIS_PAGE :
			self.WIDGET = TAB.One(state=self.STATE)
			self.WIDGET.STR_TAB_NAME = self.LABEL_NAME

			if self.FILENAME : # add label
				__label = Label.TabWithCloseForVim( \
					filename=self.FILENAME, state=self.STATE)

				self.WIDGET.addLabel(__label)

			self.WIDGET.addChild(self.EGG)

			self.EGG.WIDGET.connect("event", self.on_test)

			self.EGG.start()
			self.append_tab()
		else :
			self.WIDGET = self.LIST_TAB[self.NOTEBOOK.get_current_page()]
			if self.WIDGET.Child.CHILD_TYPE == child.TYPE_GVIM :
				self.WIDGET.Child.remote_send("\033:e %s<CR>" % self.FILENAME)
				self.WIDGET.INSTANCE_LABEL.set_label(self.FILENAME)
			else :
				self.WIDGET = TAB.One(state=self.STATE)

				__label = Label.TabWithCloseForVim( \
					filename=self.FILENAME, state=self.STATE)
				self.WIDGET.addLabel(__label)
				self.WIDGET.addChild(self.EGG)

				self.EGG.start()
				self.append_tab()

		self.connect()

	def on_test (self, parm1, parm2) :
		return

	def connect (self) : pass

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "gvim.py"

==> vee_2.5-1.tar.gz: vee-2.5/src/child/gvim.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk, os, time, base64, marshal
import GConf, child, Label, __BASIC__, TAB, Conf, func, i18n

_ = i18n.gettext()

class egg (__BASIC__.egg) :

	CHILD_TYPE = child.TYPE_GVIM
	SIGNAL_REMOVE = "plug-removed"

	SERVERNAME = "VEE_%s"
	STR_SERVERNAME = "VEE_%s"
	VIM_TITLESTRING = "\033:set title titlestring=%t\n:\n\n"

	FILENAME = str()

	def __init__ (self, **kwargs) :
		__BASIC__.egg.__init__(self, **kwargs)

		if kwargs.has_key("filename") :
			if kwargs["filename"] : self.FILENAME = kwargs["filename"]

		self.GCONF_CLIENT = GConf.Client()
		self.GVIM_COMMAND = \
			self.GCONF_CLIENT.get_value(Conf.SCHEMA["command-gvim"]["key"])

	def make (self) :
		self.WIDGET = gtk.Socket()
		self.WIDGET.set_property("has-focus", True)
		self.WIDGET.set_property("can-default", True)
		self.WIDGET.set_property("can-focus", True)
		self.WIDGET.set_property("is-focus", True)
		self.WIDGET.set_property("sensitive", True)
		self.WIDGET.set_property("receives-default", True)
		self.WIDGET.show()

	def start (self) :
		self.PLUG_ADDED = 1

		__chdir = ""
		if self.FILENAME :
			self.FILENAME = func.escape_path(self.FILENAME)
			__chdir = "cd %s;" % \
				func.escape_path(os.path.dirname(self.FILENAME))
			self.store_recent()

		self.SERVERNAME = self.STR_SERVERNAME % int(time.time())
		cmd = "%s %s --socketid %i --servername %s %s" % \
			(__chdir, self.GVIM_COMMAND, \
				self.WIDGET.get_id(), self.SERVERNAME, self.FILENAME)
		i, o, e = os.popen3(cmd, "t")

	def openFile (self, filename) :
		self.FILENAME = filename
		self.remote(filename, "isFile")
		self.store_recent()

	def remote (self, command, isfile=False) :
		__chdir = ""
		if isfile :
			__chdir = "cd %s;" % \
				func.escape_path(os.path.dirname(command))

		os.system( \
			"%s %s --servername \"%s\" --remote \"%s\"" % \
			(__chdir, self.GVIM_COMMAND, self.SERVERNAME, command))

	def remote_send (self, command) :
		os.system( \
			"%s --servername \"%s\" --remote-send \"%s\"" % \
			(self.GVIM_COMMAND, self.SERVERNAME, command))

	def get_title (self) :
		return self.FILENAME

	def exit (self) :
		self.remote_send("\033:qa<CR>")

	def store_recent (self) :
		__data = self.GCONF_CLIENT.get_value( \
			Conf.SCHEMA["recent-opened-files"]["key"])

		list_files = list()
		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_files = __data1
		except EOFError :
			pass

		if self.FILENAME in list_files :
			# remove old one and make new one be 1st.
			del(list_files[list_files.index(self.FILENAME)])

		list_files = [self.FILENAME,] + list_files

		__data = marshal.dumps(list_files)
		__data0 = base64.encodestring(__data)

		self.GCONF_CLIENT.set_value_by_conf( \
			"recent-opened-files", \
			__data0 \
		)

class tab (__BASIC__.tab) :

	LABEL_NAME = _("GVIM")
	FILENAME = None
	OPEN_IN_THIS_PAGE = False

	def __init__ (self, state, **kwargs) :

		__BASIC__.tab.__init__(self, state, **kwargs)

		if kwargs.has_key("filename") :
			#if os.path.exists(kwargs["filename"]) :
			#	self.FILENAME = kwargs["filename"]
			self.FILENAME = kwargs["filename"]

		if kwargs.has_key("openInThisPage") :
			self.OPEN_IN_THIS_PAGE = kwargs["openInThisPage"]

	def getEgg (self) :
		self.EGG = egg(filename=self.FILENAME)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		if not self.OPEN_IN_THIS_PAGE :
			self.WIDGET = TAB.One(state=self.STATE)
			self.WIDGET.STR_TAB_NAME = self.LABEL_NAME

			if self.FILENAME : # add label
				__label = Label.TabWithCloseForVim( \
					filename=self.FILENAME, state=self.STATE)

				self.WIDGET.addLabel(__label)

			self.WIDGET.addChild(self.EGG)

			self.EGG.WIDGET.connect("event", self.on_test)

			self.EGG.start()
			self.append_tab()
		else :
			self.WIDGET = self.LIST_TAB[self.NOTEBOOK.get_current_page()]
			if self.WIDGET.Child.CHILD_TYPE == child.TYPE_GVIM :
				self.WIDGET.Child.remote_send("\033:e %s<CR>" % self.FILENAME)
				self.WIDGET.INSTANCE_LABEL.set_label(self.FILENAME)
			else :
				self.WIDGET = TAB.One(state=self.STATE)

				__label = Label.TabWithCloseForVim( \
					filename=self.FILENAME, state=self.STATE)
				self.WIDGET.addLabel(__label)
				self.WIDGET.addChild(self.EGG)

				self.EGG.start()
				self.append_tab()

		self.connect()

	def on_test (self, parm1, parm2) :
		return

	def connect (self) : pass

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "gvim.py"
